Crate grabapl_template_ffi

Crate grabapl_template_ffi 

This FFI crate exposes any functionality of grabapl and the custom semantics to other languages.

This example uses the Diplomat tool to automatically generate idiomatic FFI bindings to multiple target languages.

See the main README.md for information on how to build this crate and integrate it into a different language project.

For more inspiration on FFI crates, the other clients in the example_clients directory.

Modules

ffi
This module is sent to Diplomat to automatically generate FFI bindings from functions and types on both the Rust and the target language side.